@@ -16,8 +16,9 @@ use Config::Std;
 use Data::Dumper qw/Dumper/;
 use SVG::Calendar;
 use Path::Tiny;
+use FindBin qw/$Bin/;
 
-our $VERSION = version->new('0.3.10');
+our $VERSION = version->new('0.3.11');
 
 my %option = (
     moon     => {},
@@ -141,7 +142,7 @@ sub main {
 sub show_template {
 
     require File::ShareDir;
-    my $dir = path( File::ShareDir::dist_dir('SVG-Calendar') );
+    my $dir = path( eval { File::ShareDir::dist_dir('SVG-Calendar') } || ( $Bin, '..', 'templates' )  );
     print $dir->path('calendar.svg')->slurp;
 
     return exit 0;
@@ -284,7 +285,7 @@ svgcal.pl - Creates the pages for a calendar in SVG format
 
 =head1 VERSION
 
-This documentation refers to svgcal.pl version 0.3.10.
+This documentation refers to svgcal.pl version 0.3.11.
 
 =head1 SYNOPSIS
 
