@@ -22,7 +22,7 @@ use Image::ExifTool qw/ImageInfo/;
 use English '-no_match_vars';
 use base qw/Exporter/;
 
-our $VERSION   = version->new('0.3.10');
+our $VERSION   = version->new('0.3.11');
 our @EXPORT_OK = qw//;
 
 Readonly my $MARGIN_RATIO             => 0.04;
@@ -381,7 +381,7 @@ sub output {
 
     my $fh;
     my %option = ( EVAL_PERL => 1 );
-    $option{INCLUDE_PATH} = dist_dir('SVG-Calendar');
+    $option{INCLUDE_PATH} = $self->{INCLUDE_PATH} || dist_dir('SVG-Calendar');
     if ( $self->{path} ) {
         $option{INCLUDE_PATH} .= ':' . $self->{path};
     }
@@ -561,7 +561,7 @@ SVG::Calendar - Creates calendars in SVG format which can be printed
 
 =head1 VERSION
 
-This documentation refers to SVG::Calendar version 0.3.10.
+This documentation refers to SVG::Calendar version 0.3.11.
 
 =head1 SYNOPSIS
 
